@@ -145,7 +145,7 @@ int i2c_register_entry(struct i2c_client *client, const char *prefix,
 	goto out_free_name;
 
  free_slot:
-	while (ctl_template[len].procname)
+	while (ctl_template[len].ctl_name)
 		len++;
 	tbl = kmalloc(sizeof(*tbl) + sizeof(ctl_table) * (len + 1), 
 				  GFP_KERNEL);
